@@ -1,9 +1,7 @@
-# -*- coding:utf-8 -*-
 #
 # Copyright 2015 Hewlett-Packard Enterprise
 #
 # SPDX-License-Identifier: Apache-2.0
-
 import os
 import subprocess
 from unittest import mock
@@ -34,22 +32,21 @@ shell_injection:
 
 
 class BanditBaselineToolTests(testtools.TestCase):
-
     @classmethod
     def setUpClass(cls):
         # Set up prior to running test class
         # read in content used for temporary file contents
-        with open('examples/mktemp.py') as fd:
+        with open("examples/mktemp.py") as fd:
             cls.temp_file_contents = fd.read()
 
     def setUp(self):
         # Set up prior to run each test case
-        super(BanditBaselineToolTests, self).setUp()
+        super().setUp()
         self.current_directory = os.getcwd()
 
     def tearDown(self):
         # Tear down after running each test case
-        super(BanditBaselineToolTests, self).tearDown()
+        super().tearDown()
         os.chdir(self.current_directory)
 
     def test_bandit_baseline(self):
@@ -58,57 +55,72 @@ class BanditBaselineToolTests(testtools.TestCase):
         repo_directory = self.useFixture(fixtures.TempDir()).path
 
         # get benign and findings examples
-        with open('examples/okay.py') as fd:
+        with open("examples/okay.py") as fd:
             benign_contents = fd.read()
 
-        with open('examples/os_system.py') as fd:
+        with open("examples/os_system.py") as fd:
             malicious_contents = fd.read()
 
-        contents = {'benign_one.py': benign_contents,
-                    'benign_two.py': benign_contents,
-                    'malicious.py': malicious_contents}
+        contents = {
+            "benign_one.py": benign_contents,
+            "benign_two.py": benign_contents,
+            "malicious.py": malicious_contents,
+        }
 
         # init git repo, change directory to it
         git_repo = git.Repo.init(repo_directory)
-        git_repo.index.commit('Initial commit')
+        git_repo.index.commit("Initial commit")
         os.chdir(repo_directory)
 
-        with open('bandit.yaml', 'wt') as fd:
+        with open("bandit.yaml", "wt") as fd:
             fd.write(config)
 
         # create three branches, first has only benign, second adds malicious,
         # third adds benign
 
-        branches = [{'name': 'benign1',
-                     'files': ['benign_one.py'],
-                     'expected_return': 0},
+        branches = [
+            {
+                "name": "benign1",
+                "files": ["benign_one.py"],
+                "expected_return": 0,
+            },
+            {
+                "name": "malicious",
+                "files": ["benign_one.py", "malicious.py"],
+                "expected_return": 1,
+            },
+            {
+                "name": "benign2",
+                "files": ["benign_one.py", "malicious.py", "benign_two.py"],
+                "expected_return": 0,
+            },
+        ]
 
-                    {'name': 'malicious',
-                     'files': ['benign_one.py', 'malicious.py'],
-                     'expected_return': 1},
-
-                    {'name': 'benign2',
-                     'files': ['benign_one.py', 'malicious.py',
-                               'benign_two.py'],
-                     'expected_return': 0}]
-
-        baseline_command = ['bandit-baseline', '-c', 'bandit.yaml', '-r', '.',
-                            '-p', 'test']
+        baseline_command = [
+            "bandit-baseline",
+            "-c",
+            "bandit.yaml",
+            "-r",
+            ".",
+            "-p",
+            "test",
+        ]
 
         for branch in branches:
-            branch['branch'] = git_repo.create_head(branch['name'])
-            git_repo.head.reference = branch['branch']
+            branch["branch"] = git_repo.create_head(branch["name"])
+            git_repo.head.reference = branch["branch"]
             git_repo.head.reset(working_tree=True)
 
-            for f in branch['files']:
-                with open(f, 'wt') as fd:
+            for f in branch["files"]:
+                with open(f, "wt") as fd:
                     fd.write(contents[f])
 
-            git_repo.index.add(branch['files'])
-            git_repo.index.commit(branch['name'])
+            git_repo.index.add(branch["files"])
+            git_repo.index.commit(branch["name"])
 
-            self.assertEqual(branch['expected_return'],
-                             subprocess.call(baseline_command))
+            self.assertEqual(
+                branch["expected_return"], subprocess.call(baseline_command)
+            )
 
     def test_main_non_repo(self):
         # Test that bandit gracefully exits when there is no git repository
@@ -117,27 +129,28 @@ class BanditBaselineToolTests(testtools.TestCase):
         os.chdir(repo_dir)
 
         # assert the system exits with code 2
-        self.assertRaisesRegex(SystemExit, '2', baseline.main)
+        self.assertRaisesRegex(SystemExit, "2", baseline.main)
 
     def test_main_git_command_failure(self):
         # Test that bandit does not run when the Git command fails
         repo_directory = self.useFixture(fixtures.TempDir()).path
         git_repo = git.Repo.init(repo_directory)
-        git_repo.index.commit('Initial Commit')
+        git_repo.index.commit("Initial Commit")
         os.chdir(repo_directory)
 
-        additional_content = 'additional_file.py'
-        with open(additional_content, 'wt') as fd:
+        additional_content = "additional_file.py"
+        with open(additional_content, "wt") as fd:
             fd.write(self.temp_file_contents)
         git_repo.index.add([additional_content])
-        git_repo.index.commit('Additional Content')
+        git_repo.index.commit("Additional Content")
 
-        with mock.patch('git.Repo.commit') as mock_git_repo_commit:
+        with mock.patch("git.Repo.commit") as mock_git_repo_commit:
             mock_git_repo_commit.side_effect = git.exc.GitCommandError(
-                'commit', '')
+                "commit", ""
+            )
 
             # assert the system exits with code 2
-            self.assertRaisesRegex(SystemExit, '2', baseline.main)
+            self.assertRaisesRegex(SystemExit, "2", baseline.main)
 
     def test_main_no_parent_commit(self):
         # Test that bandit exits when there is no parent commit detected when
@@ -145,11 +158,11 @@ class BanditBaselineToolTests(testtools.TestCase):
         repo_directory = self.useFixture(fixtures.TempDir()).path
 
         git_repo = git.Repo.init(repo_directory)
-        git_repo.index.commit('Initial Commit')
+        git_repo.index.commit("Initial Commit")
         os.chdir(repo_directory)
 
         # assert the system exits with code 2
-        self.assertRaisesRegex(SystemExit, '2', baseline.main)
+        self.assertRaisesRegex(SystemExit, "2", baseline.main)
 
     def test_main_subprocess_error(self):
         # Test that bandit handles a CalledProcessError when attempting to run
@@ -157,24 +170,24 @@ class BanditBaselineToolTests(testtools.TestCase):
         repo_directory = self.useFixture(fixtures.TempDir()).path
 
         git_repo = git.Repo.init(repo_directory)
-        git_repo.index.commit('Initial Commit')
+        git_repo.index.commit("Initial Commit")
         os.chdir(repo_directory)
 
-        additional_content = 'additional_file.py'
-        with open(additional_content, 'wt') as fd:
+        additional_content = "additional_file.py"
+        with open(additional_content, "wt") as fd:
             fd.write(self.temp_file_contents)
         git_repo.index.add([additional_content])
-        git_repo.index.commit('Additional Content')
+        git_repo.index.commit("Additional Content")
 
-        with mock.patch('subprocess.check_output') as mock_check_output:
-            mock_bandit_cmd = 'bandit_mock -b temp_file.txt'
-            mock_check_output.side_effect = (
-                subprocess.CalledProcessError('3', mock_bandit_cmd)
+        with mock.patch("subprocess.check_output") as mock_check_output:
+            mock_bandit_cmd = "bandit_mock -b temp_file.txt"
+            mock_check_output.side_effect = subprocess.CalledProcessError(
+                "3", mock_bandit_cmd
             )
 
             # assert the system exits with code 3 (returned from
             # CalledProcessError)
-            self.assertRaisesRegex(SystemExit, '3', baseline.main)
+            self.assertRaisesRegex(SystemExit, "3", baseline.main)
 
     def test_init_logger(self):
         # Test whether the logger was initialized when calling init_logger
@@ -199,17 +212,17 @@ class BanditBaselineToolTests(testtools.TestCase):
         # Test that bandit does not run when the Git command fails
         repo_directory = self.useFixture(fixtures.TempDir()).path
         git_repo = git.Repo.init(repo_directory)
-        git_repo.index.commit('Initial Commit')
+        git_repo.index.commit("Initial Commit")
         os.chdir(repo_directory)
 
-        additional_content = 'additional_file.py'
-        with open(additional_content, 'wt') as fd:
+        additional_content = "additional_file.py"
+        with open(additional_content, "wt") as fd:
             fd.write(self.temp_file_contents)
         git_repo.index.add([additional_content])
-        git_repo.index.commit('Additional Content')
+        git_repo.index.commit("Additional Content")
 
-        with mock.patch('git.Repo') as mock_git_repo:
-            mock_git_repo.side_effect = git.exc.GitCommandNotFound('clone', '')
+        with mock.patch("git.Repo") as mock_git_repo:
+            mock_git_repo.side_effect = git.exc.GitCommandNotFound("clone", "")
 
             return_value = baseline.initialize()
 
@@ -221,32 +234,32 @@ class BanditBaselineToolTests(testtools.TestCase):
         # 'dirty' when calling the initialize method
         repo_directory = self.useFixture(fixtures.TempDir()).path
         git_repo = git.Repo.init(repo_directory)
-        git_repo.index.commit('Initial Commit')
+        git_repo.index.commit("Initial Commit")
         os.chdir(repo_directory)
 
         # make the git repo 'dirty'
-        with open('dirty_file.py', 'wt') as fd:
+        with open("dirty_file.py", "wt") as fd:
             fd.write(self.temp_file_contents)
-        git_repo.index.add(['dirty_file.py'])
+        git_repo.index.add(["dirty_file.py"])
 
         return_value = baseline.initialize()
 
         # assert bandit did not run due to dirty repo
         self.assertEqual((None, None, None), return_value)
 
-    @mock.patch('sys.argv', ['bandit', '-f', 'txt', 'test'])
+    @mock.patch("sys.argv", ["bandit", "-f", "txt", "test"])
     def test_initialize_existing_report_file(self):
         # Test that bandit does not run when the output file exists (and the
         # provided output format does not match the default format) when
         # calling the initialize method
         repo_directory = self.useFixture(fixtures.TempDir()).path
         git_repo = git.Repo.init(repo_directory)
-        git_repo.index.commit('Initial Commit')
+        git_repo.index.commit("Initial Commit")
         os.chdir(repo_directory)
 
         # create an existing version of output report file
-        existing_report = "{}.{}".format(baseline.report_basename, 'txt')
-        with open(existing_report, 'wt') as fd:
+        existing_report = "{}.{}".format(baseline.report_basename, "txt")
+        with open(existing_report, "wt") as fd:
             fd.write(self.temp_file_contents)
 
         return_value = baseline.initialize()
@@ -254,14 +267,15 @@ class BanditBaselineToolTests(testtools.TestCase):
         # assert bandit did not run due to existing report file
         self.assertEqual((None, None, None), return_value)
 
-    @mock.patch('bandit.cli.baseline.bandit_args', ['-o',
-                'bandit_baseline_result'])
+    @mock.patch(
+        "bandit.cli.baseline.bandit_args", ["-o", "bandit_baseline_result"]
+    )
     def test_initialize_with_output_argument(self):
         # Test that bandit does not run when the '-o' (output) argument is
         # specified
         repo_directory = self.useFixture(fixtures.TempDir()).path
         git_repo = git.Repo.init(repo_directory)
-        git_repo.index.commit('Initial Commit')
+        git_repo.index.commit("Initial Commit")
         os.chdir(repo_directory)
 
         return_value = baseline.initialize()
@@ -274,12 +288,12 @@ class BanditBaselineToolTests(testtools.TestCase):
         # when calling the initialize method
         repo_directory = self.useFixture(fixtures.TempDir()).path
         git_repo = git.Repo.init(repo_directory)
-        git_repo.index.commit('Initial Commit')
+        git_repo.index.commit("Initial Commit")
         os.chdir(repo_directory)
 
         # create an existing version of temporary output file
         existing_temp_file = baseline.baseline_tmp_file
-        with open(existing_temp_file, 'wt') as fd:
+        with open(existing_temp_file, "wt") as fd:
             fd.write(self.temp_file_contents)
 
         return_value = baseline.initialize()
