@@ -26,7 +26,10 @@ class CsvFormatterTests(testtools.TestCase):
         }
         self.check_name = "hardcoded_bind_all_interfaces"
         self.issue = issue.Issue(
-            bandit.MEDIUM, bandit.MEDIUM, "Possible binding to all interfaces."
+            bandit.MEDIUM,
+            123,
+            bandit.MEDIUM,
+            "Possible binding to all interfaces.",
         )
         self.manager.out_file = self.tmp_fname
 
