@@ -25,7 +25,9 @@ class CustomFormatterTests(testtools.TestCase):
         }
         self.check_name = "hardcoded_bind_all_interfaces"
         self.issue = issue.Issue(
-            bandit.MEDIUM, bandit.MEDIUM, "Possible binding to all interfaces."
+            bandit.MEDIUM,
+            bandit.MEDIUM,
+            text="Possible binding to all interfaces.",
         )
         self.manager.out_file = self.tmp_fname
 
